@@ -204,14 +204,16 @@ def times():
 
     return {'day': day, 'month': month, 'date': date, 'year': year}
 
+newLine = False
 printLogMsg = False
-def logger(logFile, logMsg, printLogMsg):
+def logger(logFile, logMsg, newLine, printLogMsg):
     """ 
     Logger for calling program. 
     
-    Parameters: 
-    logFile (str): File to be logged to\n
-    logMsg (str): Message to be logged\n
+    Parameters:
+    logFile (str): File to be logged to
+    logMsg (str): Message to be logged
+    newLine (bool): Option to prepend newline
     printLogMsg (bool): Option to print log message
   
     Returns: 
@@ -222,5 +224,9 @@ def logger(logFile, logMsg, printLogMsg):
         print(logMsg)
 
     program = sys.argv[0]
-    program = program.rsplit('/', 1)[-1]
-    logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
\ No newline at end of file
+    program = program.rsplit('/', 1)[-1]\
+    
+    if(printLogMsg is True):
+        logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg))
+    else:
+        logFile.write(str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg))
\ No newline at end of file
